mcp_annotations library

MCP annotations package

Provides annotations used to expose library methods as tools in the Model Context Protocol (MCP) server.

Classes

Mcp
Annotation to mark a class, library, or method for MCP exposure.
Parameter
Annotation to provide rich metadata for individual parameters in a Tool.
Tool
Annotation that describes an MCP tool.

Enums

McpTransport
Transport protocol options for MCP servers.