execution property
Deprecated: Execution metadata will be supported in a future version.
Currently ignored. Reserved for future use to specify execution parameters like timeouts and resource limits.
Implementation
@Deprecated('Will be implemented in future version')
final Map<String, Object?>? execution;