Immutable class

Marker annotation indicating a class is immutable.

This is a stub implementation that does nothing at runtime. It exists for compatibility with code that expects the meta package.

Constructors

Immutable()
Creates an immutable marker annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited